@@ -227,7 +227,7 @@ def test_send_and_close_connection(protocol_cls):
             is_open = True
             try:
                 await websocket.recv()
-            except:
+            except Exception:
                 is_open = False
             return (data, is_open)
 
@@ -299,7 +299,7 @@ def test_send_after_protocol_close(protocol_cls):
             is_open = True
             try:
                 await websocket.recv()
-            except:
+            except Exception:
                 is_open = False
             return (data, is_open)
 
@@ -363,7 +363,7 @@ def test_duplicate_handshake(protocol_cls):
 
     async def connect(url):
         async with websockets.connect(url) as websocket:
-            data = await websocket.recv()
+            _ = await websocket.recv()
 
     with run_server(App, protocol_cls=protocol_cls) as url:
         loop = asyncio.new_event_loop()
@@ -386,7 +386,7 @@ def test_asgi_return_value(protocol_cls):
 
     async def connect(url):
         async with websockets.connect(url) as websocket:
-            data = await websocket.recv()
+            _ = await websocket.recv()
 
     with run_server(app, protocol_cls=protocol_cls) as url:
         loop = asyncio.new_event_loop()
