@@ -3,10 +3,8 @@ import signal
 import time
 from pathlib import Path
 
-import pytest
-
 from uvicorn.config import Config
-from uvicorn.supervisors import StatReload
+from uvicorn.supervisors.statreload import StatReload
 
 
 def run(sockets):
